@@ -188,7 +188,6 @@ class FresnelZonePlateSimulator(object):
 
         if energy_in_KeV <= 0.0: raise ValueError("Energy must be > 0")
         if n_points <= 0: raise ValueError("Number of integration points must be > 0")
-        if n_points > 200000: raise ValueError("Number of integration points must be <= 200000")
 
         if at.height <= 0.0: raise ValueError("ZP Height must be > 0")
         if at.b_min <= 0.0: raise ValueError("ZP outermost zone width must be > 0")
@@ -674,6 +673,7 @@ class FresnelZonePlateSimulator(object):
         return numpy.divide(I, I_0)
 
 from PyQt5.QtWidgets import QApplication, QWidget, QHBoxLayout
+import time
 
 if __name__ == "__main__":
     app = QApplication([])
@@ -689,10 +689,16 @@ if __name__ == "__main__":
                                                                n_slices=3),
                                    attributes=FZPAttributes())
 
-    zs.initialize(energy_in_KeV=8.0, n_points=10000)
+    zs.initialize(energy_in_KeV=8.0, n_points=5000, multipool=True)
+
+    t0 = time.time()
 
     map_int, _, efficiency = zs.simulate()
 
+    t1 = time.time()
+
+    print(("Time:" + str(t1-t0)))
+
     print("Efficiency:", efficiency)
 
     container = QWidget()
